inferpy.inference.variational package
=====================================

Subpackages
-----------

.. toctree::

   inferpy.inference.variational.loss_functions

Submodules
----------

inferpy.inference.variational.svi module
----------------------------------------

.. automodule:: inferpy.inference.variational.svi
   :members:
   :undoc-members:
   :show-inheritance:

inferpy.inference.variational.vi module
---------------------------------------

.. automodule:: inferpy.inference.variational.vi
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: inferpy.inference.variational
   :members:
   :undoc-members:
   :show-inheritance:
